@@ -472,8 +472,8 @@ WHERE t1.code LIKE (SELECT t2.code || '.%'
 with recursive t(n) as (values (1) union all select n+1 from t where n < 100)
 select sum(n) from t;
 =
-WITH RECURSIVE t(n)
-  AS (VALUES (1)
+WITH RECURSIVE t(n) AS
+     (VALUES (1)
 \n\
       UNION ALL
 \n\
@@ -487,14 +487,23 @@ WITH RECURSIVE t(n)
 with cte_1 as (select 1), cte_2 as (select * from cte_1)
 select * from cte_2
 =
-WITH cte_1 AS (SELECT 1)
+WITH cte_1 AS
+     (SELECT 1)
 \n\
-   , cte_2 AS (SELECT *
-               FROM cte_1)
+   , cte_2 AS
+     (SELECT *
+      FROM cte_1)
 \n\
   SELECT *
   FROM cte_2
 
+with cte_1 as (select 1), cte_2 as (select * from cte_1)
+select * from cte_2
+=
+WITH cte_1 AS (SELECT 1), cte_2 AS (SELECT * FROM cte_1) SELECT * FROM cte_2
+:
+{'raw_stream': True}
+
 SELECT 1 FROM ONLY "public"."produit" x WHERE "produit_id"
 OPERATOR(pg_catalog.=) $1 FOR KEY SHARE OF x
 =
@@ -502,3 +511,72 @@ SELECT 1
 FROM ONLY public.produit AS x
 WHERE produit_id OPERATOR(pg_catalog.=) $1
 FOR KEY SHARE OF x
+
+create table my_table (created_at timestamptz not null default (current_timestamp at time zone 'UTC'), constraint in_the_past check (created_at <= (current_timestamp at time zone 'UTC')))
+=
+CREATE TABLE my_table (
+    created_at timestamptz NOT NULL DEFAULT (CURRENT_TIMESTAMP AT TIME ZONE 'UTC')
+  , CONSTRAINT in_the_past CHECK (created_at <= CURRENT_TIMESTAMP AT TIME ZONE 'UTC')
+)
+:
+{'special_functions': True}
+
+create table my_table (created_at timestamptz not null default ('1 hour'::interval + current_timestamp at time zone 'UTC'))
+=
+CREATE TABLE my_table (
+  created_at timestamptz NOT NULL DEFAULT CAST('1 hour' AS interval) + (CURRENT_TIMESTAMP AT TIME ZONE 'UTC')
+)
+:
+{'special_functions': True}
+
+create table my_table (created_at timestamptz not null default (now() at local))
+=
+CREATE TABLE my_table (
+  created_at timestamptz NOT NULL DEFAULT (now() AT LOCAL)
+)
+:
+{'special_functions': True}
+
+SELECT jt.* FROM
+ my_films,
+ JSON_TABLE (js, '$.favorites[*]' COLUMNS (
+   id FOR ORDINALITY,
+   kind text PATH '$.kind',
+   title text PATH '$.films[*].title' WITH WRAPPER,
+   director text PATH '$.films[*].director' WITH WRAPPER)) AS jt
+=
+SELECT jt.*
+FROM my_films
+   , json_table(js, '$.favorites[*]'
+                COLUMNS (id FOR ORDINALITY
+                       , kind text PATH '$.kind'
+                       , title text PATH '$.films[*].title' WITH UNCONDITIONAL WRAPPER
+                       , director text PATH '$.films[*].director' WITH UNCONDITIONAL WRAPPER)) AS jt
+
+SELECT * FROM JSON_TABLE (favorites, '$.favorites[*]'
+COLUMNS (
+  user_id FOR ORDINALITY,
+  NESTED '$.movies[*]'
+    COLUMNS (
+    movie_id FOR ORDINALITY,
+    mname text PATH '$.name',
+    director text),
+  NESTED '$.books[*]'
+    COLUMNS (
+      book_id FOR ORDINALITY,
+      bname text PATH '$.name',
+      NESTED '$.authors[*]'
+        COLUMNS (
+          author_id FOR ORDINALITY,
+          author_name text PATH '$.name'))))
+=
+SELECT *
+FROM json_table(favorites, '$.favorites[*]'
+                COLUMNS (user_id FOR ORDINALITY
+                       , NESTED PATH '$.movies[*]' COLUMNS (movie_id FOR ORDINALITY
+                                                          , mname text PATH '$.name'
+                                                          , director text)
+                       , NESTED PATH '$.books[*]' COLUMNS (book_id FOR ORDINALITY
+                                                         , bname text PATH '$.name'
+                                                         , NESTED PATH '$.authors[*]' COLUMNS (author_id FOR ORDINALITY
+                                                                                             , author_name text PATH '$.name'))))
